@@ -14,6 +14,16 @@ def print_events_to_screen(events):
         print '\t', flavor, polarity, value
 
 
+def create_modglobes_samples_file(samples, N_mu):
+    file_obj = open('samples', 'w')
+    file_obj.write('%d\n' % len(samples))
+    file_obj.write('%g\n' % N_mu)
+    for E, l, angle in samples:
+        file_obj.write('%g %g %g\n' % (E, l, angle))
+    file_obj.close()
+
+
+
 def create_plot(name, results, use_matplotlib=True):
     """Create plot with matplotlib"""
 
@@ -36,7 +46,7 @@ def create_plot(name, results, use_matplotlib=True):
         if use_matplotlib:
             plt.plot(x, y, 'ro')
             plt.xlabel("Neutrino energy [GeV]")
-            plt.ylabel(r'Flux /(m${}^2$ 100 MeV)')
+            plt.ylabel(r'Flux /(m${}^2$ GeV)')
 
             plt.savefig('avg_%s_%s.eps' % (name, key))
 
@@ -46,3 +56,5 @@ def create_plot(name, results, use_matplotlib=True):
         for sorted_x in x:
             file_obj.write('%f %f\n' % (sorted_x, par[sorted_x]))
         file_obj.close()
+
+        print key, 'sum', sum(y)
